You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@allura.apache.org by br...@apache.org on 2020/10/30 21:47:30 UTC

[allura] branch master updated (00845ba -> cbdb55c)

This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a change to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git.


    from 00845ba  Strip leading or trailing dashes when suggesting project shortnames
     new 2958c91  upgraded SimpleMDE to EasyMDE
     new 4601aae  simplemde toolbar speparators are now displayed correctly fixed some missdisplayed easymde toolbar icons the three buttons 'preview, fullscreen and guide' are now on the right side again
     new feb95d1  LICENSES updated for EasyMDE instead of SimpleMDE
     new 39da7e1  deleted min-height: 60px styles. not needed anymore
     new 67838e0  - the browser's own spell checker will work now
     new 3e2f085  [#8260] [#7954] allow spellchecker on desktop; but keep better experience on Android
     new 184f7f8  [#8260] custom build of EasyMDE so we can access CodeMirror lib https://github.com/Ionaru/easy-markdown-editor/pull/263
     new 1706e14  [#8260] remove styling code no longer needed with codemirror upgrade
     new aca2f28  [#8260] avoid style bleed onto a button; update SimpleMDE->EasyMDE terms
     new cbdb55c  [#8260] add text to preview button, its an important one

The 10 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 Allura/LICENSE                                     |  6 ++--
 Allura/allura/lib/widgets/form_fields.py           |  4 +--
 .../lib/widgets/resources/css/easymde.min.css      |  7 ++++
 .../lib/widgets/resources/css/markitup_sf.css      | 21 +++++++++---
 .../lib/widgets/resources/css/simplemde.min.css    |  7 ----
 .../allura/lib/widgets/resources/js/easymde.min.js |  7 ++++
 .../allura/lib/widgets/resources/js/sf_markitup.js | 40 +++++-----------------
 .../lib/widgets/resources/js/simplemde.min.js      | 14 --------
 Allura/allura/nf/allura/css/site_style.css         |  4 ---
 Allura/allura/public/nf/js/memorable.js            |  6 ++--
 LICENSE                                            |  6 ++--
 rat-excludes.txt                                   |  4 +--
 12 files changed, 51 insertions(+), 75 deletions(-)
 create mode 100644 Allura/allura/lib/widgets/resources/css/easymde.min.css
 delete mode 100644 Allura/allura/lib/widgets/resources/css/simplemde.min.css
 create mode 100644 Allura/allura/lib/widgets/resources/js/easymde.min.js
 delete mode 100644 Allura/allura/lib/widgets/resources/js/simplemde.min.js


[allura] 02/10: simplemde toolbar speparators are now displayed correctly fixed some missdisplayed easymde toolbar icons the three buttons 'preview, fullscreen and guide' are now on the right side again

Posted by br...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit 4601aae09a07a94f38492a21eb7f2d522eb9a106
Author: domark <do...@s-kapi.com>
AuthorDate: Tue Oct 27 10:29:18 2020 +0100

    simplemde toolbar speparators are now displayed correctly
    fixed some missdisplayed easymde toolbar icons
    the three buttons 'preview, fullscreen and guide' are now on the right side again
---
 Allura/allura/lib/widgets/resources/css/markitup_sf.css | 11 ++++++++---
 1 file changed, 8 insertions(+), 3 deletions(-)

diff --git a/Allura/allura/lib/widgets/resources/css/markitup_sf.css b/Allura/allura/lib/widgets/resources/css/markitup_sf.css
index 292c061..1c0345d 100644
--- a/Allura/allura/lib/widgets/resources/css/markitup_sf.css
+++ b/Allura/allura/lib/widgets/resources/css/markitup_sf.css
@@ -35,10 +35,12 @@
   border-bottom: none;
   border-bottom-left-radius: 0;
   border-bottom-right-radius: 0;
+  overflow: hidden;
 }
 .markdown_edit .CodeMirror-scroll {
   min-height: 60px;
   max-height: 500px;
+  overflow: auto !important;
 }
 .markdown_edit .CodeMirror-fullscreen .CodeMirror-scroll {
   max-height: none;
@@ -59,6 +61,9 @@
 .editor-toolbar.disabled-for-preview a:not(.fa-eye):not(.fa-arrows-alt):not(.fa-columns)::before {
   color: #BBB;
 }
+.editor-toolbar button {
+  float: none;
+}
 
 .CodeMirror .CodeMirror-code .cm-comment {
   font-family: monospace;
@@ -75,9 +80,9 @@
     color: #999;
 }
 /* move these buttons to the right, they are a different type of button */
-.editor-toolbar .fa-eye,
-.editor-toolbar .fa-arrows-alt,
-.editor-toolbar .fa-question-circle {
+.editor-toolbar button.preview,
+.editor-toolbar button.fullscreen,
+.editor-toolbar button.guide {
   float: right;
 }
 .editor-toolbar.fullscreen {


[allura] 09/10: [#8260] avoid style bleed onto a button; update SimpleMDE->EasyMDE terms

Posted by br...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit aca2f28f31ca0b99d71eebee182dd53254797d48
Author: Dave Brondsema <db...@slashdotmedia.com>
AuthorDate: Fri Oct 30 20:47:32 2020 +0000

    [#8260] avoid style bleed onto a button; update SimpleMDE->EasyMDE terms
---
 Allura/allura/lib/widgets/resources/js/sf_markitup.js | 2 +-
 Allura/allura/nf/allura/css/site_style.css            | 4 ----
 Allura/allura/public/nf/js/memorable.js               | 6 +++---
 rat-excludes.txt                                      | 4 ++--
 4 files changed, 6 insertions(+), 10 deletions(-)

diff --git a/Allura/allura/lib/widgets/resources/js/sf_markitup.js b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
index 7d34752..d676126 100644
--- a/Allura/allura/lib/widgets/resources/js/sf_markitup.js
+++ b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
@@ -81,7 +81,7 @@ $(window).load(function() {
             });
             Memorable.add(editor);
             // https://github.com/codemirror/CodeMirror/issues/1576#issuecomment-19146595
-            // can't use simplemde's shortcuts settings, since those only hook into bindings set up for each button
+            // can't use easymde's shortcuts settings, since those only hook into bindings set up for each button
             editor.codemirror.options.extraKeys.Home = "goLineLeft";
             editor.codemirror.options.extraKeys.End = "goLineRight";
 
diff --git a/Allura/allura/nf/allura/css/site_style.css b/Allura/allura/nf/allura/css/site_style.css
index 9f1f444..77e4c7c 100644
--- a/Allura/allura/nf/allura/css/site_style.css
+++ b/Allura/allura/nf/allura/css/site_style.css
@@ -163,10 +163,6 @@ html {
   -webkit-font-smoothing: antialiased;
 }
 
-.link {
-  color: #0077aa;
-}
-
 ul {
   margin-left: 30px;
   margin-bottom: 1em;
diff --git a/Allura/allura/public/nf/js/memorable.js b/Allura/allura/public/nf/js/memorable.js
index 9ef07a7..f5b5428 100644
--- a/Allura/allura/public/nf/js/memorable.js
+++ b/Allura/allura/public/nf/js/memorable.js
@@ -192,17 +192,17 @@ Memorable.InputBasic = (function() {
 
 
 /**
- * Class describing a field backed by SimpleMDE, as identified by the passed instance of `SimpleMDE` provided, with specific methods for
+ * Class describing a field backed by EasyMDE, as identified by the passed instance of `EasyMDE` provided, with specific methods for
  * getting & setting the value, and finding it's parent form
  *
- * @property obj: the SimpleMDE object describing the field to be tracked
+ * @property obj: the EasyMDE object describing the field to be tracked
  * @property watchEvent: the name of the event to watch to detect when changes have been made
  * @property watchObj: the object instance to watch for events on; editor.codemirror per their docs
  * @property $el: the jquery object representing the actual input field on the page
  */
 Memorable.InputMDE = (function() {
     /**
-     * @param obj: A SimpleMDE object representing the input field
+     * @param obj: A EasyMDE object representing the input field
      * @constructor
      */
     function InputMDE(obj) {
diff --git a/rat-excludes.txt b/rat-excludes.txt
index f73e853..03f25ea 100644
--- a/rat-excludes.txt
+++ b/rat-excludes.txt
@@ -19,13 +19,13 @@ Allura/allura/lib/widgets/resources/css/colorPicker.css
 Allura/allura/lib/widgets/resources/css/jqfontselector.css
 Allura/allura/lib/widgets/resources/css/jquery.tagsinput.css
 Allura/allura/lib/widgets/resources/css/show-hint.css
-Allura/allura/lib/widgets/resources/css/simplemde.min.css
+Allura/allura/lib/widgets/resources/css/easymde.min.css
 Allura/allura/lib/widgets/resources/js/jqfontselector.js
 Allura/allura/lib/widgets/resources/js/jquery.autosize-min.js
 Allura/allura/lib/widgets/resources/js/jquery.colorPicker.js
 Allura/allura/lib/widgets/resources/js/jquery.tagsinput.js
 Allura/allura/lib/widgets/resources/js/show-hint.js
-Allura/allura/lib/widgets/resources/js/simplemde.min.js
+Allura/allura/lib/widgets/resources/js/easymde.min.js
 Allura/allura/nf/responsive/scss/_settings.scss
 Allura/allura/public/nf/css/blueprint/
 Allura/allura/public/nf/css/chosen.min.css


[allura] 06/10: [#8260] [#7954] allow spellchecker on desktop; but keep better experience on Android

Posted by br...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit 3e2f0851f2b55cfc2cd5ed1ad3a8362e21069f12
Author: Dave Brondsema <db...@slashdotmedia.com>
AuthorDate: Fri Oct 30 20:46:18 2020 +0000

    [#8260] [#7954] allow spellchecker on desktop; but keep better experience on Android
---
 Allura/allura/lib/widgets/resources/js/sf_markitup.js | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/Allura/allura/lib/widgets/resources/js/sf_markitup.js b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
index e233e3d..831e076 100644
--- a/Allura/allura/lib/widgets/resources/js/sf_markitup.js
+++ b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
@@ -58,7 +58,9 @@ $(window).load(function() {
               autofocus: false,
               spellChecker: false, // https://forge-allura.apache.org/p/allura/tickets/7954/
               indentWithTabs: false,
-              inputStyle: 'contenteditable',
+              // contenteditable allows native spellcheck and works fine for desktop browsers and ios (14)
+              // but its buggy on android and textarea works better https://github.com/codemirror/CodeMirror/issues/6349 https://github.com/codemirror/CodeMirror/issues/6145
+              inputStyle: navigator.userAgent.match(/Android/i) ? 'textarea' : 'contenteditable',
               tabSize: 4,
               toolbar: toolbar,
               previewRender: previewRender,


[allura] 07/10: [#8260] custom build of EasyMDE so we can access CodeMirror lib https://github.com/Ionaru/easy-markdown-editor/pull/263

Posted by br...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit 184f7f87c8cf62bfa7421b343d90ccaf28f66f38
Author: Dave Brondsema <db...@slashdotmedia.com>
AuthorDate: Fri Oct 30 20:43:21 2020 +0000

    [#8260] custom build of EasyMDE so we can access CodeMirror lib https://github.com/Ionaru/easy-markdown-editor/pull/263
---
 Allura/allura/lib/widgets/resources/js/easymde.min.js | 2 +-
 Allura/allura/lib/widgets/resources/js/sf_markitup.js | 3 ++-
 2 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/Allura/allura/lib/widgets/resources/js/easymde.min.js b/Allura/allura/lib/widgets/resources/js/easymde.min.js
index d551d6f..4771250 100644
--- a/Allura/allura/lib/widgets/resources/js/easymde.min.js
+++ b/Allura/allura/lib/widgets/resources/js/easymde.min.js
@@ -4,4 +4,4 @@
  * @link https://github.com/ionaru/easy-markdown-editor
  * @license MIT
  */
-!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this).EasyMDE=e()}}((function(){return function e(t,n,r){function i(a,l){if(!n[a]){if(!t[a]){var s="function"==typeof require&&require;if(!l&&s)return s(a,!0);if(o)return o(a,!0);var c=new Error("Cannot find module '"+a+"'");throw c.code="MO [...]
\ No newline at end of file
+!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this).EasyMDE=e()}}((function(){return function e(t,n,r){function i(a,l){if(!n[a]){if(!t[a]){var s="function"==typeof require&&require;if(!l&&s)return s(a,!0);if(o)return o(a,!0);var c=new Error("Cannot find module '"+a+"'");throw c.code="MO [...]
\ No newline at end of file
diff --git a/Allura/allura/lib/widgets/resources/css/markitup_sf.css b/Allura/allura/lib/widgets/resources/css/markitup_sf.css
index 4ca284e..af5f8a5 100644
--- a/Allura/allura/lib/widgets/resources/css/markitup_sf.css
+++ b/Allura/allura/lib/widgets/resources/css/markitup_sf.css
@@ -83,6 +83,14 @@
 .editor-toolbar button.guide {
   float: right;
 }
+.editor-toolbar button.preview {
+  width: 70px;  /* for "Preview" extra text */
+}
+.editor-toolbar button.preview::after {
+  content: ' Preview';
+  font-size: 12px;
+  font-family: inherit;
+}
 .editor-toolbar.fullscreen {
   /* for some reason the "nowrap" setting causes our floated elements to be offset in Firefox, when fullscreen */
   white-space: inherit;


[allura] 08/10: [#8260] remove styling code no longer needed with codemirror upgrade

Posted by br...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit 1706e14850b9cdfa6d141ac820fe1fc673fea2cc
Author: Dave Brondsema <db...@slashdotmedia.com>
AuthorDate: Fri Oct 30 20:46:57 2020 +0000

    [#8260] remove styling code no longer needed with codemirror upgrade
---
 .../allura/lib/widgets/resources/js/sf_markitup.js | 29 ----------------------
 1 file changed, 29 deletions(-)

diff --git a/Allura/allura/lib/widgets/resources/js/sf_markitup.js b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
index b225674..7d34752 100644
--- a/Allura/allura/lib/widgets/resources/js/sf_markitup.js
+++ b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
@@ -96,35 +96,6 @@ $(window).load(function() {
 
             editor.render();
 
-            // shared at https://github.com/codemirror/CodeMirror/issues/2143#issuecomment-140100969
-            function updateSectionHeaderStyles(cm, change) {
-              var lines = cm.lineCount();
-              for (var i = Math.max(0, change.from.line-1); i <= Math.min(change.to.line+1, lines-1); i++) {
-                var line = cm.getLineHandle(i);
-                cm.removeLineClass(line, 'text', 'cm-header');
-                cm.removeLineClass(line, 'text', 'cm-header-1');
-                cm.removeLineClass(line, 'text', 'cm-header-2');
-                var lineTokens = cm.getLineTokens(i);
-                var tok = lineTokens[0];
-                if (!tok || !tok.type || tok.type.indexOf('header') === -1) {
-                  // first token could be some spaces, try 2nd
-                  tok = lineTokens[1];
-                }
-                if (tok && tok.type && tok.type.indexOf('header') !== -1
-                  && tok.string !== '#') { // not ATX header style, which starts with #
-                  var classes = tok.type.
-                    split(' ').
-                    filter(function(cls) { return cls.indexOf('header') === 0; }).
-                    map(function (cls) { return 'cm-' + cls; }).
-                    join(' ');
-                  var prev_line = cm.getLineHandle(i-1);
-                  cm.addLineClass(prev_line, 'text', classes);
-                }
-              }
-            }
-            editor.codemirror.on("change", updateSectionHeaderStyles);
-            updateSectionHeaderStyles(editor.codemirror, {from: {line: 0}, to: {line: editor.codemirror.lineCount()}});
-
             function drawTable(editor) {
               var cm = editor.codemirror;
               cm.replaceSelection(


[allura] 01/10: upgraded SimpleMDE to EasyMDE

Posted by br...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit 2958c918c9a6e0af2719210d6b308b5b6fdb88fd
Author: domark <do...@s-kapi.com>
AuthorDate: Tue Oct 27 10:12:29 2020 +0100

    upgraded SimpleMDE to EasyMDE
---
 Allura/allura/lib/widgets/form_fields.py                  |  4 ++--
 Allura/allura/lib/widgets/resources/css/easymde.min.css   |  7 +++++++
 Allura/allura/lib/widgets/resources/css/simplemde.min.css |  7 -------
 Allura/allura/lib/widgets/resources/js/easymde.min.js     |  7 +++++++
 Allura/allura/lib/widgets/resources/js/sf_markitup.js     |  2 +-
 Allura/allura/lib/widgets/resources/js/simplemde.min.js   | 14 --------------
 6 files changed, 17 insertions(+), 24 deletions(-)

diff --git a/Allura/allura/lib/widgets/form_fields.py b/Allura/allura/lib/widgets/form_fields.py
index 5ef2ed0..d64d3df 100644
--- a/Allura/allura/lib/widgets/form_fields.py
+++ b/Allura/allura/lib/widgets/form_fields.py
@@ -285,10 +285,10 @@ class MarkdownEdit(ew.TextArea):
         for r in super(MarkdownEdit, self).resources():
             yield r
         yield ew.JSLink('js/jquery.lightbox_me.js')
-        yield ew.CSSLink('css/simplemde.min.css', compress=False)
+        yield ew.CSSLink('css/easymde.min.css', compress=False)
         yield ew.CSSLink('css/markitup_sf.css')
         yield ew.CSSLink('css/show-hint.css')
-        yield ew.JSLink('js/simplemde.min.js')
+        yield ew.JSLink('js/easymde.min.js')
         yield ew.JSLink('js/sf_markitup.js')
         yield ew.JSLink('js/show-hint.js')
         yield ew.JSLink('js/usermentions-helper.js')
diff --git a/Allura/allura/lib/widgets/resources/css/easymde.min.css b/Allura/allura/lib/widgets/resources/css/easymde.min.css
new file mode 100644
index 0000000..1958862
--- /dev/null
+++ b/Allura/allura/lib/widgets/resources/css/easymde.min.css
@@ -0,0 +1,7 @@
+/**
+ * easymde v2.12.1
+ * Copyright Jeroen Akkerman
+ * @link https://github.com/ionaru/easy-markdown-editor
+ * @license MIT
+ */
+ .CodeMirror{font-family:monospace;height:300px;color:#000;direction:ltr}.CodeMirror-lines{padding:4px 0}.CodeMirror pre.CodeMirror-line,.CodeMirror pre.CodeMirror-line-like{padding:0 4px}.CodeMirror-gutter-filler,.CodeMirror-scrollbar-filler{background-color:#fff}.CodeMirror-gutters{border-right:1px solid #ddd;background-color:#f7f7f7;white-space:nowrap}.CodeMirror-linenumber{padding:0 3px 0 5px;min-width:20px;text-align:right;color:#999;white-space:nowrap}.CodeMirror-guttermarker{color [...]
diff --git a/Allura/allura/lib/widgets/resources/css/simplemde.min.css b/Allura/allura/lib/widgets/resources/css/simplemde.min.css
deleted file mode 100644
index eb8ad9b..0000000
--- a/Allura/allura/lib/widgets/resources/css/simplemde.min.css
+++ /dev/null
@@ -1,7 +0,0 @@
-/**
- * simplemde v1.7.1
- * Copyright Next Step Webs, Inc.
- * @link https://github.com/NextStepWebs/simplemde-markdown-editor
- * @license MIT
- */
-.CodeMirror{color:#000}.CodeMirror-lines{padding:4px 0}.CodeMirror pre{padding:0 4px}.CodeMirror-gutter-filler,.CodeMirror-scrollbar-filler{background-color:#fff}.CodeMirror-gutters{border-right:1px solid #ddd;background-color:#f7f7f7;white-space:nowrap}.CodeMirror-linenumber{padding:0 3px 0 5px;min-width:20px;text-align:right;color:#999;white-space:nowrap}.CodeMirror-guttermarker{color:#000}.CodeMirror-guttermarker-subtle{color:#999}.CodeMirror-cursor{border-left:1px solid #000;border-r [...]
\ No newline at end of file
diff --git a/Allura/allura/lib/widgets/resources/js/easymde.min.js b/Allura/allura/lib/widgets/resources/js/easymde.min.js
new file mode 100644
index 0000000..d551d6f
--- /dev/null
+++ b/Allura/allura/lib/widgets/resources/js/easymde.min.js
@@ -0,0 +1,7 @@
+/**
+ * easymde v2.12.1
+ * Copyright Jeroen Akkerman
+ * @link https://github.com/ionaru/easy-markdown-editor
+ * @license MIT
+ */
+!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this).EasyMDE=e()}}((function(){return function e(t,n,r){function i(a,l){if(!n[a]){if(!t[a]){var s="function"==typeof require&&require;if(!l&&s)return s(a,!0);if(o)return o(a,!0);var c=new Error("Cannot find module '"+a+"'");throw c.code="MO [...]
\ No newline at end of file
diff --git a/Allura/allura/lib/widgets/resources/js/sf_markitup.js b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
index ae47044..e04810a 100644
--- a/Allura/allura/lib/widgets/resources/js/sf_markitup.js
+++ b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
@@ -51,7 +51,7 @@ $(window).load(function() {
               }
             ];
 
-            var editor = new SimpleMDE({
+            var editor = new EasyMDE({
               element: $textarea[0],
               autoDownloadFontAwesome: false,
               autofocus: false,
diff --git a/Allura/allura/lib/widgets/resources/js/simplemde.min.js b/Allura/allura/lib/widgets/resources/js/simplemde.min.js
deleted file mode 100644
index e30ca89..0000000
--- a/Allura/allura/lib/widgets/resources/js/simplemde.min.js
+++ /dev/null
@@ -1,14 +0,0 @@
-/**
- * simplemde v1.10.0
- * Copyright Next Step Webs, Inc.
- * @link https://github.com/NextStepWebs/simplemde-markdown-editor
- * @license MIT
- */
-!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{var t;t="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this,t.SimpleMDE=e()}}(function(){var e;return function t(e,n,r){function i(l,a){if(!n[l]){if(!e[l]){var s="function"==typeof require&&require;if(!a&&s)return s(l,!0);if(o)return o(l,!0);var c=new Error("Cannot find module '"+l+"'");t [...]
-this.polling=new Oi,this.inaccurateSelection=!1,this.hasSelection=!1,this.composing=null}function re(){var e=_i("textarea",null,null,"position: absolute; padding: 0; width: 1px; height: 1em; outline: none"),t=_i("div",[e],null,"overflow: hidden; position: relative; width: 3px; height: 0px;");return wo?e.style.width="1000px":e.setAttribute("wrap","off"),No&&(e.style.border="1px solid black"),te(e),t}function ie(e){this.cm=e,this.lastAnchorNode=this.lastAnchorOffset=this.lastFocusNode=this [...]
-bi(t)}}}function Qt(e,t){return Zt(e,t,"gutterClick",!0)}function Jt(e){var t=this;if(nn(t),!Ti(t,e)&&!Gt(t.display,e)){Tl(e),xo&&($o=+new Date);var n=$t(t,e,!0),r=e.dataTransfer.files;if(n&&!t.isReadOnly())if(r&&r.length&&window.FileReader&&window.File)for(var i=r.length,o=Array(i),l=0,a=function(e,r){if(!t.options.allowDropFileTypes||-1!=Ii(t.options.allowDropFileTypes,e.type)){var a=new FileReader;a.onload=Ot(t,function(){var e=a.result;if(/[\x00-\x08\x0e-\x1f]{2}/.test(e)&&(e=""),o[r [...]
-(!n||s)&&(t(a.doc,s),r(a.doc,e,s))}}}r(e,null,!0)}function Yr(e,t){if(t.cm)throw new Error("This document is already in use.");e.doc=t,t.cm=e,l(e),n(e),e.options.lineWrapping||h(e),e.options.mode=t.modeOption,Dt(e)}function Zr(e,t){if(t-=e.first,0>t||t>=e.size)throw new Error("There is no line "+(t+e.first)+" in the document.");for(var n=e;!n.lines;)for(var r=0;;++r){var i=n.children[r],o=i.chunkSize();if(o>t){n=i;break}t-=o}return n.lines[t]}function Qr(e,t,n){var r=[],i=t.line;return e [...]
-t=-t);for(var l=0,a=me(this.doc,e);t>l;++l){var s=ft(this,a,"div");if(null==o?o=s.left:s.left=o,a=Un(this,s,i,n),a.hitSide)break}return a},moveV:Ht(function(e,t){var n=this,r=this.doc,i=[],o=!n.display.shift&&!r.extend&&r.sel.somethingSelected();if(r.extendSelectionsBy(function(l){if(o)return 0>e?l.from():l.to();var a=ft(n,l.head,"div");null!=l.goalColumn&&(a.left=l.goalColumn),i.push(a.left);var s=Un(n,a,e,t);return"page"==t&&l==r.sel.primary()&&Fn(n,null,ht(n,s,"div").top-a.top),s},zl) [...]
-var r=e._handlers||(e._handlers={}),i=r[t]||(r[t]=[]);i.push(n)}},Ol=[],Hl=e.off=function(e,t,n){if(e.removeEventListener)e.removeEventListener(t,n,!1);else if(e.detachEvent)e.detachEvent("on"+t,n);else for(var r=Ci(e,t,!1),i=0;i<r.length;++i)if(r[i]==n){r.splice(i,1);break}},Wl=e.signal=function(e,t){var n=Ci(e,t,!0);if(n.length)for(var r=Array.prototype.slice.call(arguments,2),i=0;i<n.length;++i)n[i].apply(null,r)},Il=null,El=30,Dl=e.Pass={toString:function(){return"CodeMirror.Pass"}}, [...]
-},{name:"msgenny",mime:"text/x-msgenny",mode:"mscgen",ext:["msgenny"]}];for(var t=0;t<e.modeInfo.length;t++){var n=e.modeInfo[t];n.mimes&&(n.mime=n.mimes[0])}e.findModeByMIME=function(t){t=t.toLowerCase();for(var n=0;n<e.modeInfo.length;n++){var r=e.modeInfo[n];if(r.mime==t)return r;if(r.mimes)for(var i=0;i<r.mimes.length;i++)if(r.mimes[i]==t)return r}},e.findModeByExtension=function(t){for(var n=0;n<e.modeInfo.length;n++){var r=e.modeInfo[n];if(r.ext)for(var i=0;i<r.ext.length;i++)if(r. [...]
-"ordered-list":/^(\s*)\d+\.\s+/},l={quote:"> ","unordered-list":"* ","ordered-list":"1. "},s=r.line;s<=i.line;s++)!function(r){var i=e.getLine(r);i=n[t]?i.replace(o[t],"$1"):l[t]+i,e.replaceRange(i,{line:r,ch:0},{line:r,ch:99999999999999})}(s);e.focus()}}function I(e,t,n,r){if(!/editor-preview-active/.test(e.codemirror.getWrapperElement().lastChild.className)){r="undefined"==typeof r?n:r;var i,o=e.codemirror,l=a(o),s=n,c=r,u=o.getCursor("start"),d=o.getCursor("end");l[t]?(i=o.getLine(u.l [...]
\ No newline at end of file


[allura] 03/10: LICENSES updated for EasyMDE instead of SimpleMDE

Posted by br...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit feb95d130abab1b3a80570dafff3974542eadc0f
Author: domark <do...@s-kapi.com>
AuthorDate: Fri Oct 30 09:24:46 2020 +0100

    LICENSES updated for EasyMDE instead of SimpleMDE
---
 Allura/LICENSE | 6 +++---
 LICENSE        | 6 +++---
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/Allura/LICENSE b/Allura/LICENSE
index 72f7af2..9ff796f 100644
--- a/Allura/LICENSE
+++ b/Allura/LICENSE
@@ -270,10 +270,10 @@ For details, see:
     allura/public/nf/css/font-awesome.min.css
     allura/public/nf/fonts/
 
-SimpleMDE markdown editor (https://github.com/NextStepWebs/simplemde-markdown-editor/) is available under the MIT
+EasyMDE markdown editor (https://github.com/Ionaru/easy-markdown-editor) is available under the MIT
 license. For details, see:
-    allura/lib/widgets/resources/js/simplemde.min.js
-    allura/lib/widgets/resources/css/simplemde.min.css
+    allura/lib/widgets/resources/js/easymde.min.js
+    allura/lib/widgets/resources/css/easymde.min.css
 
 Python markdown extension for checklists (https://github.com/FND/markdown-checklist) is available under the MIT
 license. For details, see:
diff --git a/LICENSE b/LICENSE
index 1910445..46ba1eb 100644
--- a/LICENSE
+++ b/LICENSE
@@ -280,10 +280,10 @@ Source code available at https://github.com/twitter/twemoji
 For details, see:
     Allura/allura/public/nf/js/twemoji.min.js
 
-SimpleMDE markdown editor (https://github.com/NextStepWebs/simplemde-markdown-editor/) is available under the MIT
+EasyMDE markdown editor (https://github.com/Ionaru/easy-markdown-editor) is available under the MIT
 license. For details, see:
-    Allura/allura/lib/widgets/resources/js/simplemde.min.js
-    Allura/allura/lib/widgets/resources/css/simplemde.min.css
+    Allura/allura/lib/widgets/resources/js/easymde.min.js
+    Allura/allura/lib/widgets/resources/css/easymde.min.css
 
 Build scripts from Sphinx (http://sphinx-doc.org/):
     Allura/docs/make.bat


[allura] 04/10: deleted min-height: 60px styles. not needed anymore

Posted by br...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit 39da7e12f6544d160a5217edd5d96bc5acc33fa6
Author: domark <do...@s-kapi.com>
AuthorDate: Fri Oct 30 10:52:37 2020 +0100

    deleted min-height: 60px styles. not needed anymore
---
 Allura/allura/lib/widgets/resources/css/markitup_sf.css | 2 --
 Allura/allura/lib/widgets/resources/js/sf_markitup.js   | 1 +
 2 files changed, 1 insertion(+), 2 deletions(-)

diff --git a/Allura/allura/lib/widgets/resources/css/markitup_sf.css b/Allura/allura/lib/widgets/resources/css/markitup_sf.css
index 1c0345d..4ca284e 100644
--- a/Allura/allura/lib/widgets/resources/css/markitup_sf.css
+++ b/Allura/allura/lib/widgets/resources/css/markitup_sf.css
@@ -30,7 +30,6 @@
 }
 .markdown_edit .CodeMirror {
   color: rgb(85, 85, 85);
-  min-height: 60px;
   height: auto;
   border-bottom: none;
   border-bottom-left-radius: 0;
@@ -38,7 +37,6 @@
   overflow: hidden;
 }
 .markdown_edit .CodeMirror-scroll {
-  min-height: 60px;
   max-height: 500px;
   overflow: auto !important;
 }
diff --git a/Allura/allura/lib/widgets/resources/js/sf_markitup.js b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
index e04810a..c85abd4 100644
--- a/Allura/allura/lib/widgets/resources/js/sf_markitup.js
+++ b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
@@ -53,6 +53,7 @@ $(window).load(function() {
 
             var editor = new EasyMDE({
               element: $textarea[0],
+              minHeight: "60px",
               autoDownloadFontAwesome: false,
               autofocus: false,
               spellChecker: false, // https://forge-allura.apache.org/p/allura/tickets/7954/


[allura] 05/10: - the browser's own spell checker will work now

Posted by br...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit 67838e089eae5aa12b617d49b31038cd623e3249
Author: domark <do...@s-kapi.com>
AuthorDate: Fri Oct 30 11:15:30 2020 +0100

    - the browser's own spell checker will work now
---
 Allura/allura/lib/widgets/resources/js/sf_markitup.js | 1 +
 1 file changed, 1 insertion(+)

diff --git a/Allura/allura/lib/widgets/resources/js/sf_markitup.js b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
index c85abd4..e233e3d 100644
--- a/Allura/allura/lib/widgets/resources/js/sf_markitup.js
+++ b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
@@ -58,6 +58,7 @@ $(window).load(function() {
               autofocus: false,
               spellChecker: false, // https://forge-allura.apache.org/p/allura/tickets/7954/
               indentWithTabs: false,
+              inputStyle: 'contenteditable',
               tabSize: 4,
               toolbar: toolbar,
               previewRender: previewRender,
diff --git a/Allura/allura/lib/widgets/resources/js/sf_markitup.js b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
index 831e076..b225674 100644
--- a/Allura/allura/lib/widgets/resources/js/sf_markitup.js
+++ b/Allura/allura/lib/widgets/resources/js/sf_markitup.js
@@ -17,7 +17,8 @@
        under the License.
 */
 
-/*global SimpleMDE, _replaceSelection, Memorable */
+/*global EasyMDE, _replaceSelection, Memorable */
+window.CodeMirror = EasyMDE.CodeMirror; // https://github.com/Ionaru/easy-markdown-editor/pull/263
 $(window).load(function() {
     if(!window.markdown_init){
         window.markdown_init = true;


[allura] 10/10: [#8260] add text to preview button, its an important one

Posted by br...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

brondsem pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/allura.git

commit cbdb55c72e45b3418f5e1aaa1a72ac0b9be06fa5
Author: Dave Brondsema <db...@slashdotmedia.com>
AuthorDate: Fri Oct 30 21:41:37 2020 +0000

    [#8260] add text to preview button, its an important one
---
 Allura/allura/lib/widgets/resources/css/markitup_sf.css | 8 ++++++++
 1 file changed, 8 insertions(+)
